%global version 2.4.12
# rpmrelease is appended if betarelease != 0, otherwise becomes release
%global rpmrelease 4
# betarelease is either 0 or something like beta1
%global betarelease 0

# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _targetfile_postfix common.target
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: A full-featured SSL VPN solution
Name: openvpn
Version: %{version}
%if "%{betarelease}" == "0"
Release: %{rpmrelease}%{?dist}
%else
Release: 0.%{betarelease}_%{rpmrelease}%{?dist}
%endif
License: GPL-2.0-or-later
Group: Applications/Internet
URL: http://community.openvpn.net/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
%if "%{betarelease}" == "0"
Source0: http://swupdate.openvpn.org/community/releases/%{name}-%{version}.tar.gz
%else
Source0: http://swupdate.openvpn.org/community/releases/%{name}-%{version}-%{betarelease}.tar.gz
%endif
%if %{_has_systemd}
Source1: %{name}@.%{_servicefile_postfix}
Source100: %{name}.%{_targetfile_postfix}
Source2: %{name}-tmpfiles.conf
%else
Source1: %{name}.%{_servicefile_postfix}
%endif
Source3: openvpn-2.4.5-README.ec
Source4: %{name}-execpriv.defaults
Source5: %{name}.README
Patch0: openvpn-2.4.0-up-pre.patch
Patch1: openvpn-2.4.4-CVE-2016-2183.patch
Patch2: openvpn-2.4.4-lz4_version_string.patch
Patch3: openvpn-2.4.5-reneg-sec_rand.patch
Patch90: route_default_nil.patch
Patch91: auth-pam_libpam_so_filename.patch
# patches >= 100 are / should be fixed in SCM
Patch100: https://github.com/OpenVPN/openvpn/commit/3ef858b3d63c61be2f473a8dc5f1f79fa09a85d8.patch
Patch101: openvpn-2.4.9-man-txqlen.patch
Patch102: openvpn-2.4.9-remove_pid.patch
Patch103: openvpn-version_exit.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Requires: exec-tools >= 0.9
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
BuildRequires: systemd-devel
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
Requires(post): grep
# lzo >= 1.07 is also sufficient but we want to force build against lzo >= 2.00
BuildRequires: lzo-devel >= 2.00, lz4-devel >= 1.7.5, openssl-devel >= 0.9.8e
BuildRequires: pkgconfig, pam-devel, libselinux-devel, sed

%description
OpenVPN is a full-featured SSL VPN solution which can accomodate a wide
range of configurations, including remote access, site-to-site VPNs,
WiFi security, and enterprise-scale remote access solutions with load
balancing, failover, and fine-grained access-controls.

OpenVPN implements OSI layer 2 or 3 secure network extension using the
industry standard SSL/TLS protocol, supports flexible client
authentication methods based on certificates, smart cards, and/or
2-factor authentication, and allows user or group-specific access
control policies using firewall rules applied to the VPN virtual
interface. OpenVPN is not a web application proxy and does not operate
through a web browser.

%package devel
Summary: Header files and sample code for OpenVPN plug-ins development
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
Header files and sample code needed to develop plug-ins to enhance
the functionality of OpenVPN.

%prep
%if "%{betarelease}" == "0"
%setup -q
%else
%setup -q -n %{name}-%{version}-%{betarelease}
%endif
%patch0 -p1 -b .up-pre
%patch1 -p1 -b .CVE-2016-2183
%patch2 -p1 -b .lz4_version_string
%patch3 -p1 -b .reneg-sec_rand
%patch90 -p1 -b .route_default_nil
%patch91 -p1 -b .auth-pam_libpam_so_filename
%patch100 -p1 -b .3ef858b3d63c61be2f473a8dc5f1f79fa09a85d8
%patch101 -p1 -b .man-txqlen
%patch102 -p1 -b .remove_pid
%patch103 -p1 -b .version_exit
# remove patch backups
%{__rm} -vf ChangeLog.*
%{__rm} -vf sample/sample-config-files/*.conf.*
%{__sed} -i -e "s|%{_datadir}/%{name}/plugin|%{_libdir}/%{name}/plugins|g" doc/%{name}.8

%build

%configure \
  --disable-static \
  --enable-iproute2 \
  --enable-selinux \
%if %{_has_systemd}
  --enable-systemd \
%endif
  --enable-lzo \
  --enable-lz4 \
  --enable-plugin-auth-pam \
  --enable-plugin-down-root \
%{nil}

%{__make}

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p"

# remove unneeded stuff and fix permissions
%{__rm} -rf %{buildroot}%{_datadir}/doc/%{name}
%{__rm} -f %{buildroot}%{_libdir}/systemd/system/%{name}-*@.service
%{__rm} -f %{buildroot}%{_libdir}/tmpfiles.d/%{name}.conf
find %{buildroot}%{_libdir} -type f -name "*.la" -exec %{__rm} -f {} \;
find contrib/ sample/sample-*/ -type f -exec %{__chmod} -x {} \;

%{__install} -d %{buildroot}%{_sysconfdir}/%{name}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}
%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -d %{buildroot}%{_unitdir}-generators
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}@.service
%{__install} -m 0644 -p %{SOURCE100} %{buildroot}%{_unitdir}/%{name}.target
%{__ln_s} -f execpriv-generator %{buildroot}%{_unitdir}-generators/%{name}-generator
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}/execpriv.defaults
%{__install} -m 0644 -p %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}/README

%{__install} -m 0644 -p %{SOURCE3} README.ec

# remove unneeded files
%{__rm} -f README.IPv6 README.mbedtls

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{name}.target
%else
/sbin/chkconfig --add %{name}
%endif
if ! %{__grep} -q ^%{name} %{_sysconfdir}/services; then
  echo "%{name}         1194/tcp                # OpenVPN" >> %{_sysconfdir}/services
  echo "%{name}         1194/udp                # OpenVPN" >> %{_sysconfdir}/services
fi

%preun
%if %{_has_systemd}
%systemd_preun %{name}.target
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.target
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS Change* COPY* INSTALL NEWS PORTS README*
%doc doc/management-notes.txt doc/README.plugins
%doc contrib/ src/plugins/*/README.*
%doc sample/sample-{config-files,keys,scripts,windows}/
%{_sbindir}/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}.target
%{_unitdir}-generators/%{name}-generator
%else
%config %{_initrddir}/%{name}
%endif
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/execpriv.defaults
%{_sysconfdir}/%{name}/README
%{_libdir}/%{name}
%dir %{_pidbasedir}/%{name}
%{_mandir}/man8/%{name}.8*

%files devel
%defattr(-,root,root,-)
%doc sample/sample-plugins/
%{_includedir}/%{name}-*.h

%changelog
* Wed Jun 21 2023 Simon Matter <simon.matter@invoca.ch> 2.4.12-4
- fix building of beta releases
- change to SPDX license tag
- remove eval where possible
- change to *.common.service systemd files

* Mon Mar 06 2023 Simon Matter <simon.matter@invoca.ch> 2.4.12-3
- add also Wants=network-online.target to systemd unit files

* Fri Mar 03 2023 Simon Matter <simon.matter@invoca.ch> 2.4.12-2
- add network-online requirement to systemd unit files

* Fri Mar 18 2022 Simon Matter <simon.matter@invoca.ch> 2.4.12-1
- update to release 2.4.12

* Tue Jan 11 2022 Simon Matter <simon.matter@invoca.ch> 2.4.11-2
- add support for EL9

* Wed Apr 21 2021 Simon Matter <simon.matter@invoca.ch> 2.4.11-1
- update to release 2.4.11

* Thu Dec 10 2020 Simon Matter <simon.matter@invoca.ch> 2.4.10-1
- update to release 2.4.10

* Wed Jul 08 2020 Simon Matter <simon.matter@invoca.ch> 2.4.9-3
- add patch to remove pid file on exit
- add patch to make openvpn --version exit with exit code 0

* Tue Jun 30 2020 Simon Matter <simon.matter@invoca.ch> 2.4.9-2
- add patch to remove default setting of "set txqueuelen to 100"

* Fri Apr 17 2020 Simon Matter <simon.matter@invoca.ch> 2.4.9-1
- update to release 2.4.9

* Tue Apr 14 2020 Simon Matter <simon.matter@invoca.ch> 2.4.8-2
- add support for EL8

* Thu Oct 31 2019 Simon Matter <simon.matter@invoca.ch> 2.4.8-1
- update to release 2.4.8
- update patch fix-broken-fragmentation-logic-when-using-NCP
- remove patch correct-the-return-value-of-cryptoapi-RSA-signature-callbacks

* Mon Jul 29 2019 Simon Matter <simon.matter@invoca.ch> 2.4.7-2
- add patch fix-broken-fragment_mssfix-with-NCP
- add patch correct-the-return-value-of-cryptoapi-RSA-signature-callbacks

* Thu Feb 21 2019 Simon Matter <simon.matter@invoca.ch> 2.4.7-1
- update to release 2.4.7

* Wed Nov 21 2018 Simon Matter <simon.matter@invoca.ch> 2.4.6-5
- update for compatibility with exec-tools >= 0.9

* Tue Nov 20 2018 Simon Matter <simon.matter@invoca.ch> 2.4.6-3
- make it run with exec-tools

* Fri May 18 2018 Simon Matter <simon.matter@invoca.ch> 2.4.6-2
- remove support_fingerprint_authentication patch

* Tue Apr 24 2018 Simon Matter <simon.matter@invoca.ch> 2.4.6-1
- update to release 2.4.6
- add support_fingerprint_authentication patch

* Thu Mar 01 2018 Simon Matter <simon.matter@invoca.ch> 2.4.5-1
- update to release 2.4.5

* Thu Nov 16 2017 Simon Matter <simon.matter@invoca.ch> 2.4.4-4
- update reneg-sec_rand patch to v4 from Steffan Karger

* Tue Nov 14 2017 Simon Matter <simon.matter@invoca.ch> 2.4.4-3
- update reneg-sec_rand patch to v4

* Mon Nov 13 2017 Simon Matter <simon.matter@invoca.ch> 2.4.4-2
- update reneg-sec_rand patch to v3

* Thu Sep 28 2017 Simon Matter <simon.matter@invoca.ch> 2.4.4-1
- update to release 2.4.4

* Wed Jun 21 2017 Simon Matter <simon.matter@invoca.ch> 2.4.3-1
- update to release 2.4.3

* Mon Jun 19 2017 Simon Matter <simon.matter@invoca.ch> 2.4.2-4
- add two more patches from current release/2.4 branch

* Thu May 18 2017 Simon Matter <simon.matter@invoca.ch> 2.4.2-3
- add another NCP related patch from current release/2.4 branch

* Tue May 16 2017 Simon Matter <simon.matter@invoca.ch> 2.4.2-2
- add log-the-negotiated-NCP-cipher patch

* Thu May 11 2017 Simon Matter <simon.matter@invoca.ch> 2.4.2-1
- update to release 2.4.2

* Tue May 09 2017 Simon Matter <simon.matter@invoca.ch> 2.4.1-7
- create separate -devel package
- add patches from master

* Thu Apr 06 2017 Simon Matter <simon.matter@invoca.ch> 2.4.1-6
- update reneg-sec_rand patch

* Thu Apr 06 2017 Simon Matter <simon.matter@invoca.ch> 2.4.1-5
- update reneg-sec_rand patch

* Thu Apr 06 2017 Simon Matter <simon.matter@invoca.ch> 2.4.1-4
- update reneg-sec_randomize10 patch

* Tue Apr 04 2017 Simon Matter <simon.matter@invoca.ch> 2.4.1-3
- update reneg-sec_randomize patch

* Mon Apr 03 2017 Simon Matter <simon.matter@invoca.ch> 2.4.1-2
- add reneg-sec_random patch

* Thu Mar 23 2017 Simon Matter <simon.matter@invoca.ch> 2.4.1-1
- update to release 2.4.1
- remove now obsolete tls-crypt_segfault patch

* Fri Jan 20 2017 Simon Matter <simon.matter@invoca.ch> 2.4.0-4
- add tls-crypt_segfault patch

* Tue Jan 17 2017 Simon Matter <simon.matter@invoca.ch> 2.4.0-3
- update patch to fix CVE-2016-2183
- add LZ4 version string patch

* Tue Jan 03 2017 Simon Matter <simon.matter@invoca.ch> 2.4.0-1
- update to release 2.4.0
- import 2 patches from debian

* Mon Dec 12 2016 Simon Matter <simon.matter@invoca.ch> 2.3.14-1
- update to release 2.3.14

* Mon Nov 07 2016 Simon Matter <simon.matter@invoca.ch> 2.3.13-1
- update to release 2.3.13

* Thu Sep 01 2016 Simon Matter <simon.matter@invoca.ch> 2.3.12-2
- add patch to fix CVE-2016-2183

* Wed Aug 24 2016 Simon Matter <simon.matter@invoca.ch> 2.3.12-1
- update to release 2.3.12

* Wed May 11 2016 Simon Matter <simon.matter@invoca.ch> 2.3.11-1
- update to release 2.3.11

* Tue Jan 05 2016 Simon Matter <simon.matter@invoca.ch> 2.3.10-1
- update to release 2.3.10

* Thu Dec 17 2015 Simon Matter <simon.matter@invoca.ch> 2.3.9-1
- update to release 2.3.9

* Tue Aug 04 2015 Simon Matter <simon.matter@invoca.ch> 2.3.8-1
- update to release 2.3.8

* Tue Jun 09 2015 Simon Matter <simon.matter@invoca.ch> 2.3.7-1
- update to release 2.3.7

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 2.3.6-3
- small spec fixes for systemd

* Tue May 05 2015 Simon Matter <simon.matter@invoca.ch> 2.3.6-2
- add support for systemd

* Tue Dec 02 2014 Simon Matter <simon.matter@invoca.ch> 2.3.6-1
- update to release 2.3.6

* Wed Oct 29 2014 Simon Matter <simon.matter@invoca.ch> 2.3.5-1
- update to release 2.3.5

* Sat May 03 2014 Simon Matter <simon.matter@invoca.ch> 2.3.4-1
- update to release 2.3.4

* Thu Apr 10 2014 Simon Matter <simon.matter@invoca.ch> 2.3.3-1
- update to release 2.3.3

* Tue Jun 04 2013 Simon Matter <simon.matter@invoca.ch> 2.3.2-1
- update to release 2.3.2

* Tue May 14 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-9
- fix a bug in init script

* Tue May 14 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-8
- improve init script

* Mon May 13 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-7
- add custom init script

* Fri May 10 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-6
- improve init script patch

* Mon May 06 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-5
- improve init script patch

* Sat Apr 20 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-4
- improve init script patch

* Tue Apr 16 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-3
- add up-pre patch

* Mon Apr 15 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-2
- improve init script patch

* Tue Apr 02 2013 Simon Matter <simon.matter@invoca.ch> 2.3.1-1
- update to release 2.3.1

* Mon Jan 21 2013 Simon Matter <simon.matter@invoca.ch> 2.3.0-1
- update to release 2.3.0

* Thu Dec 22 2011 Simon Matter <simon.matter@invoca.ch> 2.2.2-1
- update to release 2.2.2

* Wed Aug 10 2011 Simon Matter <simon.matter@invoca.ch> 2.2.1-3
- change defattr to fix directory permissions on EL6

* Thu Jul 28 2011 Simon Matter <simon.matter@invoca.ch> 2.2.1-2
- add openvpn entries to /etc/services if missing

* Thu Jul 07 2011 Simon Matter <simon.matter@invoca.ch> 2.2.1-1
- update to release 2.2.1

* Thu Apr 28 2011 Simon Matter <simon.matter@invoca.ch> 2.2.0-1
- update to release 2.2.0

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 2.1.4-2
- mass rebuild

* Wed Nov 10 2010 Simon Matter <simon.matter@invoca.ch> 2.1.4-1
- update to release 2.1.4

* Thu Sep 02 2010 Simon Matter <simon.matter@invoca.ch> 2.1.3-1
- update to release 2.1.3

* Mon Aug 16 2010 Simon Matter <simon.matter@invoca.ch> 2.1.2-1
- update to release 2.1.2

* Sat Dec 12 2009 Simon Matter <simon.matter@invoca.ch> 2.1.1-1
- update to release 2.1.1

* Fri Dec 11 2009 Simon Matter <simon.matter@invoca.ch> 2.1.0-1
- update to release 2.1.0

* Sat Nov 21 2009 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc22_1
- update to release 2.1_rc22

* Fri Nov 13 2009 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc21_1
- update to release 2.1_rc21

* Mon Oct 05 2009 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc20_1
- update to release 2.1_rc20
- change license tag to GPLv2+

* Thu Jul 16 2009 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc19_1
- update to release 2.1_rc19

* Mon Jun 08 2009 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc18_1
- update to release 2.1_rc18

* Mon Jun 01 2009 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc17_1
- update to release 2.1_rc17

* Wed May 20 2009 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc16_1
- update to release 2.1_rc16
- remove now obsolete oldgcc patch

* Thu Nov 20 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc15_1
- update to release 2.1_rc15

* Wed Nov 19 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc14_1
- update to release 2.1_rc14

* Thu Oct 09 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc13_1
- update to release 2.1_rc13

* Tue Sep 23 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc12_1
- update to release 2.1_rc12

* Mon Sep 15 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc11_1
- update to release 2.1_rc11

* Thu Sep 11 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc10_1
- update to release 2.1_rc10

* Fri Aug 01 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc9_1
- update to release 2.1_rc9

* Sun Jun 15 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc8_1
- update to release 2.1_rc8
- automatically build all plugins, but remove the broken ones first

* Fri Feb 08 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc7_2
- add patch to fix bug in close_tun() to reestablish broken tunnels

* Wed Jan 30 2008 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc7_1
- update to release 2.1_rc7

* Thu Sep 20 2007 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc4_2
- move plugins to _libdir
- move easy-rsa to _datadir
- change init script to not start openvpn by default

* Thu Apr 26 2007 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc4_1
- update to release 2.1_rc4

* Tue Apr 24 2007 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc3_1
- update to release 2.1_rc3

* Wed Feb 28 2007 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc2_1
- update to release 2.1_rc2
- add patches for older gcc

* Wed Nov 22 2006 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc1_2
- add /var/run/openvpn to package

* Fri Nov 03 2006 Simon Matter <simon.matter@invoca.ch> 2.1-0.rc1_1
- update to release 2.1_rc1

* Mon Oct 02 2006 Simon Matter <simon.matter@invoca.ch> 2.1-0.beta16_1
- update to release 2.1_beta16

* Tue Sep 12 2006 Simon Matter <simon.matter@invoca.ch> 2.1-0.beta15_1
- update to release 2.1_beta15

* Sat Apr 22 2006 Simon Matter <simon.matter@invoca.ch> 2.1-0.beta14_1
- update to release 2.1_beta14
- add patches for older gcc and openssl

* Wed Apr 05 2006 Simon Matter <simon.matter@invoca.ch> 2.0.6-1
- update to release 2.0.6

* Fri Nov 04 2005 Simon Matter <simon.matter@invoca.ch> 2.0.5-1
- update to release 2.0.5

* Wed Nov 02 2005 Simon Matter <simon.matter@invoca.ch> 2.0.4-1
- update to release 2.0.4

* Fri Aug 26 2005 Simon Matter <simon.matter@invoca.ch> 2.0.2-1
- initial release
